@@ -210,6 +210,7 @@ xb_builder_compile_source (XbBuilderCompileHelper *helper,
 	gssize len;
 	g_autofree gchar *data = NULL;
 	g_autofree gchar *guid = xb_builder_source_get_guid (source);
+	g_autoptr(GPtrArray) children_copy = NULL;
 	g_autoptr(GInputStream) istream = NULL;
 	g_autoptr(GMarkupParseContext) ctx = NULL;
 	g_autoptr(GTimer) timer = g_timer_new ();
@@ -268,8 +269,13 @@ xb_builder_compile_source (XbBuilderCompileHelper *helper,
 
 	/* add the children to the main document */
 	children = xb_builder_node_get_children (root_tmp);
+	children_copy = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	for (guint i = 0; i < children->len; i++) {
-		g_autoptr(XbBuilderNode) bn = g_object_ref (g_ptr_array_index (children, i));
+		XbBuilderNode *bn = g_ptr_array_index (children, i);
+		g_ptr_array_add (children_copy, g_object_ref (bn));
+	}
+	for (guint i = 0; i < children_copy->len; i++) {
+		XbBuilderNode *bn = g_ptr_array_index (children_copy, i);
 		xb_builder_node_unlink (bn);
 		xb_builder_node_add_child (root, bn);
 	}
@@ -696,6 +702,8 @@ xb_builder_compile (XbBuilder *self, XbBuilderCompileFlags flags, GCancellable *
 	g_autoptr(XbBuilderCompileHelper) helper = NULL;
 
 	g_return_val_if_fail (XB_IS_BUILDER (self), NULL);
+	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	/* this is inferred */
 	if (flags & XB_BUILDER_COMPILE_FLAG_SINGLE_LANG)
@@ -762,7 +770,7 @@ xb_builder_compile (XbBuilder *self, XbBuilderCompileFlags flags, GCancellable *
 	for (guint i = 0; i < priv->fixups->len; i++) {
 		XbBuilderFixup *fixup = g_ptr_array_index (priv->fixups, i);
 		if (!xb_builder_fixup_node (fixup, helper->root, error))
-			return FALSE;
+			return NULL;
 	}
 
 	/* only include the highest priority translation */
@@ -865,6 +873,8 @@ xb_builder_ensure (XbBuilder *self, GFile *file, XbBuilderCompileFlags flags,
 
 	g_return_val_if_fail (XB_IS_BUILDER (self), NULL);
 	g_return_val_if_fail (G_IS_FILE (file), NULL);
+	g_return_val_if_fail (cancellable == NULL || G_IS_CANCELLABLE (cancellable), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
 	/* watch the blob, so propagate flags */
 	if (flags & XB_BUILDER_COMPILE_FLAG_WATCH_BLOB)
@@ -896,7 +906,8 @@ xb_builder_ensure (XbBuilder *self, GFile *file, XbBuilderCompileFlags flags,
 		}
 
 		/* reload the cached silo with the new file data */
-		if (g_strcmp0 (xb_silo_get_guid (silo_tmp), guid) == 0) {
+		if (g_strcmp0 (xb_silo_get_guid (silo_tmp), guid) == 0 ||
+		    (flags & XB_BUILDER_COMPILE_FLAG_IGNORE_GUID) > 0) {
 			g_autoptr(GBytes) blob = xb_silo_get_bytes (silo_tmp);
 			g_debug ("loading silo with file contents");
 			if (!xb_silo_load_from_bytes (priv->silo, blob,
