@@ -4,13 +4,12 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __XB_OPCODE_PRIVATE_H
-#define __XB_OPCODE_PRIVATE_H
-
-G_BEGIN_DECLS
+#pragma once
 
 #include "xb-opcode.h"
 
+G_BEGIN_DECLS
+
 XbOpcode	*xb_opcode_new			(XbOpcodeKind	 kind,
 						 const gchar	*str,
 						 guint32	 val,
@@ -29,5 +28,3 @@ void		 xb_opcode_set_val		(XbOpcode	*self,
 gchar		*xb_opcode_get_sig		(XbOpcode	*self);
 
 G_END_DECLS
-
-#endif /* __XB_OPCODE_PRIVATE_H */
