@@ -4,15 +4,14 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __XB_QUERY_PRIVATE_H
-#define __XB_QUERY_PRIVATE_H
-
-G_BEGIN_DECLS
+#pragma once
 
 #include <glib-object.h>
 
 #include "xb-query.h"
 
+G_BEGIN_DECLS
+
 typedef enum {
 	XB_SILO_QUERY_KIND_UNKNOWN,
 	XB_SILO_QUERY_KIND_WILDCARD,
@@ -32,5 +31,3 @@ typedef struct {
 GPtrArray	*xb_query_get_sections		(XbQuery	*self);
 
 G_END_DECLS
-
-#endif /* __XB_QUERY_PRIVATE_H */
