@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __XB_SILO_EXPORT_PRIVATE_H
-#define __XB_SILO_EXPORT_PRIVATE_H
+#pragma once
 
 #include "xb-silo-export.h"
 
@@ -17,5 +16,3 @@ GString		*xb_silo_export_with_root	(XbSilo		*self,
 						 GError		**error);
 
 G_END_DECLS
-
-#endif /* __XB_SILO_EXPORT_PRIVATE_H */
