@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __XB_SILO_EXPORT_H
-#define __XB_SILO_EXPORT_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -24,5 +23,3 @@ gboolean	 xb_silo_export_file		(XbSilo		*self,
 						 GError		**error);
 
 G_END_DECLS
-
-#endif /* __XB_SILO_EXPORT_H */
