@@ -4,15 +4,14 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#ifndef __XB_STACK_PRIVATE_H
-#define __XB_STACK_PRIVATE_H
-
-G_BEGIN_DECLS
+#pragma once
 
 #include <glib-object.h>
 
 #include "xb-stack.h"
 
+G_BEGIN_DECLS
+
 XbStack		*xb_stack_new			(guint		 max_size);
 void		 xb_stack_unref			(XbStack	*self);
 XbStack		*xb_stack_ref			(XbStack	*self);
@@ -27,5 +26,3 @@ GPtrArray	*xb_stack_steal_all		(XbStack	*self);
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(XbStack, xb_stack_unref)
 
 G_END_DECLS
-
-#endif /* __XB_STACK_PRIVATE_H */
